==> haskell-newtype-0.2.2.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 newtype
version:              0.2.2.0
visibility:           public
id:                   newtype-0.2.2.0-DLepnI1K4MV6UjpzRSf6II
key:                  newtype-0.2.2.0-DLepnI1K4MV6UjpzRSf6II
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Darius Jahandarie, Conor McBride
synopsis:             A typeclass and set of functions for working with newtypes.
description:
    Per Conor McBride, the '\''Newtype'\'' typeclass represents the packing and unpacking of a @newtype@, and allows you to operate under that @newtype@ with functions such as '\''ala'\''. See "Control.Newtype" for documentation and examples.

category:             Control
abi:                  24ca7539cceea0369d45454a6e2474e3
exposed:              True
exposed-modules:      Control.Newtype
import-dirs:          /usr/lib/ghc-9.2.8/site-local/newtype-0.2.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/newtype-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype
hs-libraries:         HSnewtype-0.2.2.0-DLepnI1K4MV6UjpzRSf6II
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-newtype/html/newtype.haddock
haddock-html:         /usr/share/doc/haskell-newtype/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-newtype-0.2.2.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-newtype.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 newtype
version:              0.2.2.0
visibility:           public
id:                   newtype-0.2.2.0-Ib2Dt6U2VHsE9gZh8SysiD
key:                  newtype-0.2.2.0-Ib2Dt6U2VHsE9gZh8SysiD
license:              BSD-3-Clause
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel, Darius Jahandarie, Conor McBride
synopsis:             A typeclass and set of functions for working with newtypes.
description:
    Per Conor McBride, the '\''Newtype'\'' typeclass represents the packing and unpacking of a @newtype@, and allows you to operate under that @newtype@ with functions such as '\''ala'\''. See "Control.Newtype" for documentation and examples.

category:             Control
abi:                  12877d2c617cae1706ec68eec2374d1c
exposed:              True
exposed-modules:      Control.Newtype
import-dirs:          /usr/lib/ghc-9.4.8/site-local/newtype-0.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/newtype-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/newtype-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-newtype
hs-libraries:         HSnewtype-0.2.2.0-Ib2Dt6U2VHsE9gZh8SysiD
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-newtype/html/newtype.haddock
haddock-html:         /usr/share/doc/haskell-newtype/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
